@@ -13,58 +13,31 @@ else if (file_exists('./plugins/compatibility/functions.php'))
 
 
 
-// store the user's IMAP server in the session
-//
-function multilogin_restoreIMAPServer_do()
-{
-
-   global $_SESSION;
-
-   // get global variable for versions of PHP < 4.1
-   //
-   if (!check_php_version(4,1)) {
-      global $HTTP_SESSION_VARS;
-      $_SESSION = $HTTP_SESSION_VARS;
-   }
-
-
-   // grab all the "multilogin_..." values out of the session
-   // settings and override SM settings with them
-   //
-   foreach ($_SESSION as $key => $value)
-   {
-
-      if (strpos($key, 'multilogin_') === 0)
-      {
-         $realVarName = substr($key, 11);
-         global $$realVarName;
-         $$realVarName = $value;
-      }
-
-   }
-
-}
-
-
-
 // store the user's IMAP server in the session
 //
 function multilogin_registerIMAPServer_do()
 {
 
    // php 4.3 confuses login info when trying 
-   // to login without having legged out last time
+   // to login without having logged out last time
    //
    global $onetimepad;
    $onetimepad = '';
    compatibility_sqsession_unregister('onetimepad');
 
 
-   global $loginServer, $rememberLoginServer;
+   global $loginServer, $rememberLoginServer, $IMAPSelections;
 
    compatibility_sqextractGlobalVar('loginServer');
    compatibility_sqextractGlobalVar('rememberLoginServer');
 
+
+   if (compatibility_check_SM_version(1, 3))
+      include_once(SM_PATH . 'plugins/multilogin/config.php');
+   else
+      include_once('../plugins/multilogin/config.php');
+
+
    if (isset($rememberLoginServer) && $rememberLoginServer)
    {
       // cookie expires in 30 days
@@ -76,23 +49,27 @@ function multilogin_registerIMAPServer_do()
       setcookie('rememberLoginServer', '', (time() - 3600));
    }
 
-   $settingsList = preg_split('/\|/', $loginServer, -1, PREG_SPLIT_NO_EMPTY);
-
-   foreach ($settingsList as $settings)
+   if (is_array($IMAPSelections[$loginServer]))
    {
 
-      list($setting, $value) = preg_split('/:/', $settings, 2);
+      global $config_override;
+      compatibility_sqsession_unregister('config_override');
+////      $config_override = array();
 
-      $multiloginOverrideVarName = 'multilogin_' . $setting;
-      global $$multiloginOverrideVarName;
-      $$multiloginOverrideVarName = $value;
-      sqsession_unregister($multiloginOverrideVarName);
-      sqsession_register($value, $multiloginOverrideVarName);
+      foreach ($IMAPSelections[$loginServer] as $setting => $value)
+      {
+
+         $config_override[$setting] = $value;
+
+      }
+
+      compatibility_sqsession_register($config_override, 'config_override');
+
+
+      multilogin_sqoverride_config_do();
 
    }
 
-   multilogin_restoreIMAPServer();
-
 }
 
 
@@ -130,15 +107,10 @@ function multilogin_insertIMAPSelection_do()
    foreach (array_keys($IMAPSelections) as $IMAPServer)
    {
 
-      echo "          <OPTION VALUE=\"";
+      echo '          <OPTION VALUE="' . $IMAPServer . '"';
 
-      $optionValue = '';
-      foreach ($IMAPSelections[$IMAPServer] as $setting => $value)
-         $optionValue .= $setting . ':' . $value . '|';
-
-      echo $optionValue . '"';
       if (isset($_COOKIE['rememberLoginServer']) 
-         && $_COOKIE['rememberLoginServer'] == $optionValue)
+         && $_COOKIE['rememberLoginServer'] == $IMAPServer)
       {
          echo ' SELECTED';
          $foundMatchingLoginServer = 1;
@@ -164,4 +136,90 @@ function multilogin_insertIMAPSelection_do()
 }
 
 
+
+// This will look for config overrides in the session,
+// which must be in an array called 'config_override'.
+// If found, any values stored there will take precedence
+// over preexisting config values.
+//
+function multilogin_sqoverride_config_do()
+{
+
+   if (compatibility_sqsession_is_registered('config_override'))
+   {
+
+      global $config_override, $plugins, $squirrelmail_plugin_hooks;
+      compatibility_sqextractGlobalVar('config_override');
+
+
+      // grab all the config values out of the session
+      // settings and override current settings with them
+      //
+      foreach ($config_override as $key => $value)
+      {
+
+
+         // enable additional plugins
+         //
+         if (stristr($key, 'enable_plugins'))
+         {
+            foreach ($value as $pluginName)
+            {
+               $plugins[] = $pluginName;
+               if (function_exists('use_plugin'))
+                  use_plugin($pluginName);
+            }
+            continue;
+         }
+
+
+         // disable plugins
+         //
+         if (stristr($key, 'disable_plugins'))
+         {
+            foreach ($value as $pluginName)
+            {
+               $pluginKey = array_search($pluginName, $plugins);
+               if (!is_null($pluginKey) && $pluginKey !== FALSE)
+               {
+                  unset($plugins[$pluginKey]);
+                  if (is_array($squirrelmail_plugin_hooks))
+                     foreach (array_keys($squirrelmail_plugin_hooks) as $hookName)
+                     {
+                        unset($squirrelmail_plugin_hooks[$hookName][$pluginName]);
+                     }
+               }
+            }
+            continue;
+         }
+
+
+         //
+         // replace SquirrelMail config values
+         //
+
+         // in order to set the org_title, in the browser
+         // title bar, have to do it now (using an eval
+         // otherwise things like $_SESSION will never be
+         // found when the variable is first defined)
+         //
+         if ($key == 'org_title')
+         {
+            global $$key;
+            eval('$$key = ' . $value . ';');
+         }
+         else
+         {
+            global $$key;
+            $$key = $value;
+         }
+
+      }
+
+   }
+
+}
+
+
+
 ?>
