@@ -6,24 +6,20 @@ function squirrelmail_plugin_init_multilogin() {
 
    $squirrelmail_plugin_hooks['login_form']['multilogin'] = 'multilogin_insertIMAPSelection';
    $squirrelmail_plugin_hooks['login_before']['multilogin'] = 'multilogin_registerIMAPServer';
-   $squirrelmail_plugin_hooks['session_recall']['multilogin'] = 'multilogin_restoreIMAPServer';
+
+   // unfortunately, we can only set org_title in the title
+   // bar of the browser if we use this hook - otherwise, it's
+   // unecessary
+   //
+   $squirrelmail_plugin_hooks['webmail_top']['multilogin'] = 'multilogin_sqoverride_config';
 
 }
 
 
 
-// store the user's IMAP server in the session
-//
-function multilogin_restoreIMAPServer()
+function multilogin_version()
 {
-
-   if (defined('SM_PATH'))
-      include_once(SM_PATH . 'plugins/multilogin/functions.php');
-   else
-      include_once('../plugins/multilogin/functions.php');
-
-   multilogin_restoreIMAPServer_do();
-
+   return '2.2';
 }
 
 
@@ -59,4 +55,21 @@ function multilogin_insertIMAPSelection()
 }
 
 
+
+// present IMAP server selection pull-down
+//
+function multilogin_sqoverride_config()
+{
+
+   if (defined('SM_PATH'))
+      include_once(SM_PATH . 'plugins/multilogin/functions.php');
+   else
+      include_once('../plugins/multilogin/functions.php');
+
+   multilogin_sqoverride_config_do();
+
+}
+
+
+
 ?>
